@@ -8,9 +8,6 @@
 #![allow(deref_nullptr)]
 #![allow(clippy::missing_safety_doc)]
 
-#[macro_use]
-extern crate lazy_static;
-
 extern crate libc;
 
 #[macro_use]
@@ -25,6 +22,7 @@ pub mod xlib;
 pub mod dpms;
 pub mod glx;
 pub mod keysym;
+pub mod sync;
 pub mod xcursor;
 pub mod xf86vmode;
 pub mod xfixes;
@@ -35,6 +33,7 @@ pub mod xinput2;
 pub mod xlib_xcb;
 pub mod xmd;
 pub mod xmu;
+pub mod xpresent;
 pub mod xrecord;
 pub mod xrender;
 pub mod xshm;
